Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(322)

Unified Diff: remoting/host/it2me/it2me_native_messaging_host_main.cc

Issue 810133003: replace NULL->nullptr in src/remoting. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/it2me/it2me_native_messaging_host_main.cc
diff --git a/remoting/host/it2me/it2me_native_messaging_host_main.cc b/remoting/host/it2me/it2me_native_messaging_host_main.cc
index cf30a87f449df2a239268701cea0fa489b65e976..a89ee5296ee47c76b8609785904ba811a47c6053 100644
--- a/remoting/host/it2me/it2me_native_messaging_host_main.cc
+++ b/remoting/host/it2me/it2me_native_messaging_host_main.cc
@@ -71,9 +71,9 @@ int StartIt2MeNativeMessagingHost() {
XInitThreads();
// Required for any calls into GTK functions, such as the Disconnect and
// Continue windows. Calling with NULL arguments because we don't have
// any command line arguments for gtk to consume.
- gtk_init(NULL, NULL);
+ gtk_init(nullptr, nullptr);
#endif // OS_LINUX
// Enable support for SSL server sockets, which must be done while still
@@ -96,8 +96,8 @@ int StartIt2MeNativeMessagingHost() {
// the STD* handles at startup. So any LoadLibrary request can potentially
// be blocked. To prevent that from happening we close STDIN and STDOUT
// handles as soon as we retrieve the corresponding file handles.
- SetStdHandle(STD_INPUT_HANDLE, NULL);
- SetStdHandle(STD_OUTPUT_HANDLE, NULL);
+ SetStdHandle(STD_INPUT_HANDLE, nullptr);
+ SetStdHandle(STD_OUTPUT_HANDLE, nullptr);
#elif defined(OS_POSIX)
// The files are automatically closed.
base::File read_file(STDIN_FILENO);
@@ -71,9 +71,9 @@ int StartIt2MeNativeMessagingHost() {
XInitThreads();
// Required for any calls into GTK functions, such as the Disconnect and
- // Continue windows. Calling with NULL arguments because we don't have
+ // Continue windows. Calling with nullptr arguments because we don't have
// any command line arguments for gtk to consume.
« no previous file with comments | « remoting/host/it2me/it2me_native_messaging_host.cc ('k') | remoting/host/it2me/it2me_native_messaging_host_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698